﻿using System;
using System.Collections.Generic;
using SharePointIntegrationWeb.Model;

namespace SharePointIntegrationWeb.Controller
{
    public class MemberController
    {
        readonly DAO _dao = DAO.Instance;

        public string AddMember(String name, String email, String birthday, String phone, String address, String city, String zipCode, String memberType, String approvedBy, String position)
        {
            try
            {
                bool accepted = true;
                string info = "";

                if (String.IsNullOrWhiteSpace(name))
                {
                    info += "Navn må ikke være tomt<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(email))
                {
                    info += "E-mail må ikke være tomt<br />";
                    accepted = false;
                }
                else if (!IsValidEmail(email))
                {
                    info += "E-mail er ikke godkendt<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(birthday))
                {
                    /*
                     * Try the new input for birthday
                     */
                    info += "Fødselsdag må ikke være tomt<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(phone))
                {
                    /*
                     * Consider more test
                     */
                    info += "Telefon må ikke være tomt<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(address))
                {
                    info += "Fødselsdag må ikke være tomt<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(city))
                {
                    info += "By må ikke være tomt<br />";
                    accepted = false;
                }

                int i;
                if (String.IsNullOrWhiteSpace(zipCode))
                {
                    info += "Postnummer må ikke være tomt<br />";
                    accepted = false;
                }
                else if (zipCode.Length != 4)
                {
                    info += "Postnummer skal have 4 tal<br />";
                    accepted = false;
                }
                else if (!int.TryParse(zipCode, out i))
                {
                    // https://msdn.microsoft.com/en-us/library/bb384043.aspx
                    // Check if numeric
                    info += "Postnummer skal kun indeholde nummer<br />";
                    accepted = false;
                }


                if (String.IsNullOrWhiteSpace(memberType))
                {
                    info += "Medlems type må ikke være tomt<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(approvedBy))
                {
                    info += "Godkendt af må ikke være tomt<br />";
                    accepted = false;
                }


                if (accepted)
                {
                    DateTime datetime = Convert.ToDateTime(birthday);
                    Member member = new Member(name, email, datetime, phone, address, city, zipCode, memberType,
                        approvedBy);
                    member.Position = position;
                    if (_dao.IsEmailUsed(member.Email))
                    {
                        return "email already used";
                    }
                    int memberId = _dao.AddMember(member);
                    _dao.AddSubscibtion(memberId);
                    return "approved";
                }

                // Not accepted
                return info;
            }
            catch (Exception exception)
            {
                Membersystem.ExceptionUtility.LogException(exception, "Controller");
                return exception.Message;
            }
        }

        /**
         * http://forums.asp.net/t/1957656.aspx?Validate+an+email+address+using+c+
         */
        private bool IsValidEmail(string email)
        {
            try
            {
                var addr = new System.Net.Mail.MailAddress(email);
                return true;
            }
            catch
            {
                return false;
            }
        }

        public string GetMemberType(String email)
        {
            try
            {
                return _dao.GetMemberType(email);
            }
            catch (Exception ex)
            {
                Membersystem.ExceptionUtility.LogException(ex, "Controller");

                return "Error: " + ex.Message;
            }
        }

        public Member GetMemberObject(string email)
        {
            try
            {
                return _dao.GetMember(email);
            }
            catch (Exception ex)
            {
                Membersystem.ExceptionUtility.LogException(ex, "Controller");
                throw;
            }
        }
        public Member GetMemberObject(int id)
        {
            try
            {
                return _dao.GetMember(id);
            }
            catch (Exception ex)
            {
                Membersystem.ExceptionUtility.LogException(ex, "Controller");
                throw;
            }
        }

        public Dictionary<string, string> GetMember(string email)
        {
            Dictionary<string, string> memberInfo = new Dictionary<string, string>();
            try
            {
                Member member = _dao.GetMember(email);
                if (member == null)
                    return null;
                memberInfo["Id"] = member.Id.ToString();
                memberInfo["Name"] = member.Name;
                memberInfo["Email"] = member.Email;
                string birthday = member.Birthday.ToShortDateString();
                memberInfo["Birthday"] = birthday;
                memberInfo["Phone"] = member.Phone;
                memberInfo["Address"] = member.Address;
                memberInfo["City"] = member.City;
                memberInfo["ZipCode"] = member.ZipCode;
                memberInfo["MemberType"] = member.MemberType;
                memberInfo["Position"] = member.Position;
            }
            catch (Exception ex)
            {
                Membersystem.ExceptionUtility.LogException(ex, "Controller");

                throw;
            }
            return memberInfo;
        }

        public string EditProfile(string id, string iName, string iEmail, string iBirthday, string iPhone, string iAddress, string iCity, string iZipCode, string iMemberType, string position)
        {
            try
            {
                bool accepted = true;
                string info = "";

                if (String.IsNullOrWhiteSpace(id))
                {
                    info += "Id må ikke være tomt<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(iName))
                {
                    info += "Navn må ikke være tomt<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(iEmail))
                {
                    info += "E-mail må ikke være tomt<br />";
                    accepted = false;
                }
                else if (!IsValidEmail(iEmail))
                {
                    info += "E-mail er ikke godkendt<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(iBirthday))
                {
                    /*
                     * Try the new input for birthday
                     */
                    info += "Fødselsdag må ikke være tomt<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(iPhone))
                {
                    /*
                     * Consider more test
                     */
                    info += "Telefon må ikke være tomt<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(iAddress))
                {
                    info += "Fødselsdag må ikke være tomt<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(iCity))
                {
                    info += "By må ikke være tomt<br />";
                    accepted = false;
                }

                int i;
                if (String.IsNullOrWhiteSpace(iZipCode))
                {
                    info += "Postnummer må ikke være tomt<br />";
                    accepted = false;
                }
                else if (iZipCode.Length != 4)
                {
                    info += "Postnummer skal have 4 tal<br />";
                    accepted = false;
                }
                else if (!int.TryParse(iZipCode, out i))
                {
                    // https://msdn.microsoft.com/en-us/library/bb384043.aspx
                    // Check if numeric
                    info += "Postnummer skal kun indeholde nummer<br />";
                    accepted = false;
                }
                if (String.IsNullOrWhiteSpace(iMemberType))
                {
                    info += "Medlemstype må ikke være tomt<br />";
                    accepted = false;
                }

                if (accepted)
                {
                    Member member = new Member(iName, iEmail, DateTime.Parse(iBirthday), iPhone, iAddress, iCity, iZipCode, iMemberType, default(String));
                    member.Position = position;
                    return _dao.EditMember(id, member);
                }

                // Not accepted
                return info;
            }
            catch (Exception ex)
            {
                Membersystem.ExceptionUtility.LogException(ex, "Controller");

                return ex.Message;
            }
        }

        public string ArchiveUser(string email)
        {
            try
            {
                bool accepted = true;
                string info = "";

                if (String.IsNullOrWhiteSpace(email))
                {
                    info += "Email må ikke være tomt<br />";
                    accepted = false;
                }
                if (!IsValidEmail(email))
                {
                    info += "Email er ikke godkendt<br />";
                    accepted = false;
                }

                if (accepted)
                {
                    string message = _dao.ArchiveUser(email);
                    if (message.Equals("accepted"))
                    {
                        return "Brugeren blev ændret";
                    }
                    if (message.Equals("user not found"))
                    {
                        return "Bruger er ikke fundet i databasen";
                    }
                }
                return info;
            }
            catch (Exception ex)
            {
                Membersystem.ExceptionUtility.LogException(ex, "Controller");

                return ex.Message;
            }

        }
        public List<Member> SearchMember(string name)
        {
            try
            {
                return _dao.SearchMember(name);
            }
            catch (Exception ex)
            {
                throw new Exception(ex.Message);
            }

        }

        public List<Member> GetNonActivatedMembers()
        {
            try
            {
                return _dao.GetNonActivatedMembers();
            }
            catch (Exception)
            {

                throw;
            }
        }

        public string AcceptUser(int userId, string approvedByEmail)
        {
            string memberType = GetMemberType(approvedByEmail);
            if (memberType != "Bestyrelse")
            {
                return "du må ikke godkende bruger";
            }
            try
            {
                string message = _dao.AcceptUser(userId, approvedByEmail);
                if (message == "accepted")
                {
                    return "Godkendt";
                }
                return "Bruger er ikke fundet";
            }
            catch (Exception exception)
            {
                Membersystem.ExceptionUtility.LogException(exception, "Controller");

                return exception.Message;
            }
        }

        public string DeclineUser(int userId, string approvedByEmail)
        {
            string memberType = GetMemberType(approvedByEmail);
            if (memberType != "Bestyrelse")
            {
                return "Du må ikke afvise bruger";
            }
            try
            {
                string message = _dao.DeclineUser(userId);
                if (message == "accepted")
                {
                    return "Afvist";
                }
                return "Bruger er ikke fundet";
            }
            catch (Exception exception)
            {
                Membersystem.ExceptionUtility.LogException(exception, "Controller");

                return exception.Message;
            }
        }

        internal int NumberOfDeactivatedMembers()
        {
            return _dao.DeactivatedMembers();
        }

        public string GetCity(string zip)
        {
            return _dao.GetCity(int.Parse(zip));
        }

        public string CreateInvoice(string memberId, string iPrice)
        {
            string sub = _dao.GetSubscribtion(memberId);
            return _dao.CreateInvoice(sub, iPrice);
        }

        public string GetPrice(string memberType)
        {
            return _dao.GetPrice(memberType);
        }

        public bool PayInvoice(string invId, string subscibtionId)
        {
            _dao.PayInvoice(invId);
            return _dao.AddYearSubscribtion(subscibtionId);
        }

        public string DeleteInvoice(string invId)
        {
            return _dao.DeleteInvoice(invId);

        }

        public string GetMemberIdBySubNr(String subNr)
        {
            return _dao.GetMemberIdBySubNr(subNr);
        }

        public Dictionary<string, string> GetInvoiceInfo()
        {
            return _dao.GetInvoiceInfo();
        }

        public bool EditInvoiceInfo(string bankName, string regNr, string kontoNr, string phone, string address, string zipCode, string city, string message)
        {
            return _dao.EditInvoiceInfo(bankName, regNr, kontoNr, address, zipCode, city, phone, message);
        }

        public void DeleteAllVerificationCodes()
        {
            _dao.DeleteAllVerificationCodes();
        }
    }
}