﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Net;
using System.Net.Mail;
using iTextSharp.text;
using iTextSharp.text.html.simpleparser;
using iTextSharp.text.pdf;
using Microsoft.SharePoint.Client;
using SharePointIntegrationWeb.Controller;
using SharePointIntegrationWeb.Model;
using Attachment = System.Net.Mail.Attachment;
using File = System.IO.File;

namespace SharePointIntegrationWeb.Pages
{
    public partial class CreateInvoice : System.Web.UI.Page
    {
        private static readonly MemberController _memberController = new MemberController();
        /// <summary>
        /// Checks if the membertype is "Bestyrelse", else redirect him back to startpage.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_PreRender(object sender, EventArgs e)
        {
            string memberType = (string)Session["MemberType"];
            if (memberType != "Bestyrelse")
            {
                Response.Redirect((string)Session["StartPage"]);
            }
        }

        protected void Page_Load(object sender, EventArgs e)
        {
        }
        /// <summary>
        /// Sends input to the controller. If Price input is left empty, the system will ask the database for the
        /// standard price for his membership type.
        /// It then fires the method that created an invoice.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Submit_OnClick(object sender, EventArgs e)
        {
            String iEmail = Email.Text;
            Member member = _memberController.GetMemberObject(iEmail);
            String iPrice = Price.Text;
            if (iPrice == "")
            {
                iPrice = _memberController.GetPrice(member.MemberType);
            }
            string invoiceId = _memberController.CreateInvoice(member.Id.ToString(), iPrice);

            CreateInvoicePDF(iEmail, iPrice, invoiceId);
        }

        protected void Cancel_OnClick(object sender, EventArgs e)
        {
            Response.Redirect((string)Session["StartPage"]);
        }

        /// <summary>
        /// Creates a PDF with all invoice information.
        /// The method styles the PDF file making it look like an invoice.
        /// Uploads the file on the website server, then sends the invoice to the costumer, then uploads the invoice file to sharepoint and finally removing the invoice pdf from the website server.
        /// </summary>
        /// <param name="mail">Mail from input</param>
        /// <param name="price">Price from input or from standard price in database</param>
        /// <param name="invoiceId">Invoice id generated after inserting invoice in the database</param>
        public void CreateInvoicePDF(string mail, string price, string invoiceId)
        {
            Member member = _memberController.GetMemberObject(mail);
            string newPrice = price.Replace('.', ',');
            Dictionary<string, string> invoiceInfo = _memberController.GetInvoiceInfo();
            try
            {
                // Step 1: Creating System.IO.FileStream object
                string fileName = Server.MapPath("PDF/Faktura for " + member.Name + ".pdf");
                using (
                    FileStream fs = new FileStream(fileName,
                        FileMode.Create, FileAccess.Write, FileShare.None))
                // Step 2: Creating iTextSharp.text.Document object
                using (Document doc = new Document())
                // Step 3: Creating iTextSharp.text.pdf.PdfWriter object
                // It helps to write the Document to the Specified FileStream
                using (PdfWriter writer = PdfWriter.GetInstance(doc, fs))
                {
                    // Step 4: Openning the Document
                    var worker = new HTMLWorker(doc);
                    doc.Open();
                    worker.StartDocument();

                    // Step 5: Adding a paragraph
                    // NOTE: When we want to insert text, then we've to do it through creating paragraph

                    Paragraph headlieParagraph = new Paragraph("K19s Venner");
                    headlieParagraph.Font.Size = 25;

                    Paragraph memberIdParagraph = new Paragraph("Medlems nr: " + member.Id);
                    Paragraph memberNameParagraph = new Paragraph(member.Name);
                    Paragraph memberAddressParagraph = new Paragraph(member.Address);
                    Paragraph memberZipCodeParagraph = new Paragraph(member.ZipCode + " " + member.City);
                    Paragraph memberEmailParagraph = new Paragraph(member.Email);

                    iTextSharp.text.Image gif = iTextSharp.text.Image.GetInstance(Server.MapPath("../Images/logo.png"));
                    gif.SetAbsolutePosition(450, 720);

                    Paragraph infoParagraph1 = new Paragraph("K19s Venner");
                    Paragraph infoParagraph2 = new Paragraph("Addresse: " + invoiceInfo["Address"].TrimEnd());
                    Paragraph infoParagraph3 = new Paragraph("By: " + invoiceInfo["ZipCode"] + " " + invoiceInfo["City"].TrimEnd());
                    Paragraph infoParagraph4 = new Paragraph("Telefon: +45 " + invoiceInfo["Phone"].TrimEnd());
                    infoParagraph1.Alignment = Element.ALIGN_RIGHT;
                    infoParagraph2.Alignment = Element.ALIGN_RIGHT;
                    infoParagraph3.Alignment = Element.ALIGN_RIGHT;
                    infoParagraph4.Alignment = Element.ALIGN_RIGHT;

                    Paragraph p =
                        new Paragraph(
                            new Chunk(new iTextSharp.text.pdf.draw.LineSeparator(0.0F, 100.0F, BaseColor.WHITE,
                                Element.ALIGN_LEFT, 1)));

                    Paragraph invoiceNumberParagraph = new Paragraph("Faktura nummer: " + invoiceId);
                    Paragraph dateParagraph = new Paragraph("Dato: " + DateTime.Today.ToShortDateString());
                    Paragraph bankParagraph = new Paragraph("Bank: " + invoiceInfo["BankName"].TrimEnd());
                    Paragraph regParagraph = new Paragraph("Reg. nr: " + invoiceInfo["RegNr"].TrimEnd());
                    Paragraph acNrParagraph = new Paragraph("Konto nr: " + invoiceInfo["KontoNr"].TrimEnd());

                    dateParagraph.Alignment = Element.ALIGN_RIGHT;
                    invoiceNumberParagraph.Alignment = Element.ALIGN_RIGHT;
                    bankParagraph.Alignment = Element.ALIGN_RIGHT;
                    regParagraph.Alignment = Element.ALIGN_RIGHT;
                    acNrParagraph.Alignment = Element.ALIGN_RIGHT;


                    Paragraph invoiceParagraph = new Paragraph("Faktura");
                    invoiceParagraph.Font.Size = 25;
                    string html =
                        "<br/><table border='1'><tr><td width=\"80%\" style=\"text-align:center\"><b>Betegnelse</b></td><td width=\"20%\" style=\"text-align:center\"><b>Beløb</b></td></tr><tr><td width=\"80%\" style=\"padding-left:10px;padding-bottom:5px\">Medlemskab</td><td width=\"20%\" style=\"text-align:right\">" + newPrice + "</td></tr></table><br/>";
                    TextReader reader = new StringReader(html);

                    string total =
                        "<br/><table border='0'><tr><td width=\"80%\" style=\"text-align:right\"><b>Total DKK</b></td><td width=\"20%\" style=\"text-align:right\">" +
                        newPrice + "</td></tr></table><br/>";
                    TextReader reader2 = new StringReader(total);
                    Paragraph messageParagraph = new Paragraph(invoiceInfo["Message"].TrimEnd());
                    doc.Add(headlieParagraph);
                    doc.Add(new Paragraph("\n"));
                    doc.Add(gif);
                    doc.Add(memberIdParagraph);
                    doc.Add(memberNameParagraph);
                    doc.Add(memberAddressParagraph);
                    doc.Add(memberZipCodeParagraph);
                    doc.Add(memberEmailParagraph);
                    doc.Add(infoParagraph1);
                    doc.Add(infoParagraph2);
                    doc.Add(infoParagraph3);
                    doc.Add(infoParagraph4);
                    doc.Add(p);
                    doc.Add(invoiceNumberParagraph);
                    doc.Add(dateParagraph);
                    doc.Add(bankParagraph);
                    doc.Add(regParagraph);
                    doc.Add(acNrParagraph);

                    doc.Add(invoiceParagraph);
                    worker.Parse(reader);
                    worker.Parse(reader2);
                    doc.Add(messageParagraph);
                    worker.Close();
                    // Step 6: Closing the Document
                    doc.Close();
                }
                Response.Write(SharePointHelper.UploadInvoice(fileName, member.Name + " " + member.Id, (ClientContext)Session["clientContext"]) + " - ");
                SendInvoice(mail, fileName);
            }
            // Catching iTextSharp.text.DocumentException if any
            catch (DocumentException de)
            {
                throw de;
            }
            // Catching System.IO.IOException if any
            catch (IOException ioe)
            {
                throw ioe;
            }
        }
        /// <summary>
        /// Sends email with invoice as attachment.
        /// </summary>
        /// <param name="email">The email to send the email to</param>
        /// <param name="filePath">Filepath to PDF file on website server</param>
        private void SendInvoice(string email, string filePath)
        {
            try
            {
                MailMessage mail = new MailMessage("admin@k19svenner.onmicrosoft.com", email);
                //MailMessage mail = new MailMessage("SalikN@k19svenner.onmicrosoft.com", email);
                SmtpClient client = new SmtpClient
                {
                    Port = 587,
                    EnableSsl = true,
                    DeliveryMethod = SmtpDeliveryMethod.Network,
                    UseDefaultCredentials = false,
                    Credentials = new NetworkCredential("admin@k19svenner.onmicrosoft.com", "Vaqu1823"),
                    //Credentials = new NetworkCredential("SalikN@k19svenner.onmicrosoft.com", "pass@word1"),
                    Host = "smtp.office365.com"
                };
                Attachment attachment = new Attachment(filePath);
                mail.Attachments.Add(attachment);
                mail.Subject = "K19s Venner - Faktura";
                mail.Body = "Kære medlem" + Environment.NewLine + Environment.NewLine + "Din faktura er vedhæftet" +
                            Environment.NewLine + Environment.NewLine + "Med venlig hilsen" + Environment.NewLine +
                            "K19s Venner";
                client.Send(mail);

                attachment.Dispose();
                DeleteFile(filePath);
                Email.Text = "";
                Price.Text = "";
                Response.Write("Fakturaen blev sendt!");
            }
            catch (Exception ex)
            {
                Response.Write(ex.Message);
            }
        }

        /// <summary>
        /// Deletes the file
        /// </summary>
        /// <param name="filePath">Filepath to the file</param>
        private void DeleteFile(string filePath)
        {
            File.Delete(filePath);
        }
    }
}