﻿using System;
using System.Net;
using System.Net.Mail;
using System.Text;
using System.Web.Services;
using iTextSharp.text.pdf;
using iTextSharp.text.pdf.parser;
using Microsoft.SharePoint.Client;
using SharePointIntegrationWeb.Controller;
using SharePointIntegrationWeb.Model;
using Attachment = System.Net.Mail.Attachment;
using File = System.IO.File;

namespace SharePointIntegrationWeb.Pages
{
    public partial class CreateMember : System.Web.UI.Page
    {
        static readonly MemberController _memberController = new MemberController();
        /// <summary>
        /// Checks if the membertype is "Bestyrelse", else redirect him back to startpage.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_PreRender(object sender, EventArgs e)
        {
            string memberType = (string)Session["MemberType"];
            if (memberType != "Bestyrelse")
            {
                Response.Redirect((string)Session["StartPage"]);
            }
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            
        }
        /// <summary>
        /// The button which starts the process of creating a member.
        /// Takes all the inputs and pass it to the controller.
        /// If the member was created, the system will send him an email,
        /// and create a document library for him.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Submit_Click(object sender, EventArgs e)
        {
            String iName = Name.Text;
            String iEmail = Email.Text;
            String iBirthday = Birthday.Text;
            String iPhone = Phone.Text;
            String iZipCode = ZipCode.Text;
            String iAddress = Address.Text;
            String iCity = City2.Text;
            String iMemberType = MemberType.SelectedItem.Text;
            String iPosition = null;
            String approvedBy = (string)Session["UserEmail"];
            if (iMemberType != "Medlem")
            {
                iPosition = Position.Text;
            }
            try
            {
                string added = _memberController.AddMember(iName, iEmail, iBirthday, iPhone, iAddress, iCity, iZipCode, iMemberType, approvedBy, iPosition);

                if (added.Equals("approved"))
                {
                    statusLabel.Visible = true;
                    SendEmail(iEmail);
                    Member member = _memberController.GetMemberObject(iEmail);
                    statusLabel.Text = SharePointHelper.CreateMemberList(iEmail, member.Name + " " + member.Id,
                        (ClientContext)Session["clientContext"]);        
                    statusLabel.Text = "Medlemmet blev oprettet";
                }
                else if (added.Equals("email already used"))
                {
                    errorlabel.Text = "E-mail er allerede brugt";
                    errorlabel.Visible = true;
                }
                else
                {
                    errorlabel.Text = added;
                    errorlabel.Visible = true;
                }
            }
            catch (Exception ex)
            {
                errorlabel.Text = ex.Message;
                Membersystem.ExceptionUtility.LogException(ex, Request.RawUrl);

            }
        }
        /// <summary>
        /// Cancelling returns you to the front page.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Cancel_Click(object sender, EventArgs e)
        {
            Response.Redirect((string)Session["StartPage"]);
        }
        /// <summary>
        /// A web method that works with the client side.
        /// It's an ajax call from the markup file that calls this method.
        /// </summary>
        /// <param name="zipCode">Zip code from input</param>
        /// <returns>City name</returns>
        [WebMethod]
        public static string ZipCode_OnTextChanged(string zipCode)
        {
            string city = _memberController.GetCity(zipCode);
            return city.TrimEnd();
        }
        /// <summary>
        /// Makes the "Role" field available based on if you pick the "Bestyrelse" or "Member"
        /// in the membertype drop down.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void MemberType_OnSelectedIndexChanged(object sender, EventArgs e)
        {
            if (MemberType.SelectedIndex == 0)
            {
                Position.ReadOnly = false;
            }
            else
            {
                Position.ReadOnly = true;
                Position.Text = "";
            }

            if (ZipCode.Text.Length == 4)
            {
                string city = ZipCode_OnTextChanged(ZipCode.Text);
                if (city == "City not found")
                {
                    City.Text = "By ikke fundet";
                }
                else
                {
                    City.Text = city;
                    City2.Text = city;
                }
            }
        }
        /// <summary>
        /// Sends email to the member when he is created.
        /// Reads from a pdf file and insert it into the email.
        /// </summary>
        /// <param name="email"></param>
        private void SendEmail(string email)
        {
            string filePath = Server.MapPath("Velkommen-som-medlem-af-K19s-Venner-1.pdf");
            string logoPath = Server.MapPath("../Images/logo.png");

            try
            {
                // http://stackoverflow.com/questions/2550796/reading-pdf-content-with-itextsharp-dll-in-vb-net-or-c-sharp
                StringBuilder text = new StringBuilder();

                if (File.Exists(filePath))
                {
                    PdfReader pdfReader = new PdfReader(filePath);

                    for (int page = 1; page <= pdfReader.NumberOfPages; page++)
                    {
                        ITextExtractionStrategy strategy = new SimpleTextExtractionStrategy();
                        string currentText = PdfTextExtractor.GetTextFromPage(pdfReader, page, strategy);

                        currentText = Encoding.UTF8.GetString(ASCIIEncoding.Convert(Encoding.Default, Encoding.UTF8, Encoding.Default.GetBytes(currentText)));
                        text.Append(currentText);
                    }
                    pdfReader.Close();
                }

                Attachment imageAttachment = new Attachment(logoPath);
                imageAttachment.ContentId = "Logo.png"; ;

                MailMessage mail = new MailMessage("admin@k19svenner.onmicrosoft.com", email);
                SmtpClient client = new SmtpClient
                {
                    Port = 587,
                    EnableSsl = true,
                    DeliveryMethod = SmtpDeliveryMethod.Network,
                    UseDefaultCredentials = false,
                    Credentials = new NetworkCredential("admin@k19svenner.onmicrosoft.com", "Vaqu1823"),
                    Host = "smtp.office365.com"
                };

                mail.Subject = "K19s Venner - Velkommen";
                mail.IsBodyHtml = true;
                mail.Body = @"<img src=""cid:Logo.png"" /><br />" + text;
                mail.Attachments.Add(imageAttachment);
                client.Send(mail);
                imageAttachment.Dispose();
            }
            catch (Exception ex)
            {
                errorlabel.Text = ex.Message;
                errorlabel.Visible = true;
            }
        }
    }
}