﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using SharePointIntegrationWeb.Controller;
using SharePointIntegrationWeb.Model;

namespace SharePointIntegrationWeb.Pages
{
    public partial class Default : System.Web.UI.Page
    {
        readonly MemberController _memberController = new MemberController();
        String email = "";
        /// <summary>
        /// A SharePoint method that checks if the user needs to be redirected.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_PreInit(object sender, EventArgs e)
        {
            Uri redirectUrl;
            switch (SharePointContextProvider.CheckRedirectionStatus(Context, out redirectUrl))
            {
                case RedirectionStatus.Ok:
                    return;
                case RedirectionStatus.ShouldRedirect:
                    Response.Redirect(redirectUrl.AbsoluteUri, endResponse: true);
                    break;
                case RedirectionStatus.CanNotRedirect:
                    Response.Write("An error occurred while processing your request.");
                    Response.End();
                    break;
            }

        }
        /// <summary>
        /// Checks if the user is inside the fullscreen app part or is using the sharepoint site
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_PreRender(object sender, EventArgs e)
        {
            if (!Request.Url.ToString().Contains("SPHostTitle"))
            {
                mobileDevice.Visible = false;
            }
        }
        /// <summary>
        /// When the page loads, it makes a ClientContext when the credentials of the logged in user.
        /// It adds links to the menu based on the membertype of the logged in user.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_Load(object sender, EventArgs e)
        {
            Session.Add("StartPage", Request.RawUrl);
            // The following code gets the client context and Title property by using TokenHelper.
            // To access other properties, the app may need to request permissions on the host web.
            var spContext = SharePointContextProvider.Current.GetSharePointContext(Context);

            using (var clientContext = spContext.CreateUserClientContextForSPHost())
            {
                Session.Add("clientContext", clientContext);
                clientContext.Load(clientContext.Web);
                clientContext.ExecuteQuery();
                clientContext.Load(clientContext.Web.CurrentUser);
                clientContext.ExecuteQuery();
                email = clientContext.Web.CurrentUser.Email;
                Session.Add("UserEmail", email);

            }

            String memberType = _memberController.GetMemberType(email);

            if (memberType == "Medlem" || memberType == "Bestyrelse")
            {
                Session.Add("MemberType", memberType);
                LinkPanel.Controls.Add(
                new HtmlAnchor()
                {
                    HRef = "EditProfile.aspx",
                    InnerHtml =
                        "<div class='linkBox col-lg-3 col-md-4 col-sm-6 col-xs-12'><div class='inline-Div'><img src='../Images/edit.png'/></div><div class='inline-Div'><p class='linkBox-title'>Redigér Profil</p><p class='linkBox-text'>Redigér din egen profil</p></div></div>"
                });
                LinkPanel.Controls.Add(
                new HtmlAnchor()
                {
                    HRef = "ContactList.aspx",
                    InnerHtml =
                        "<div class='linkBox col-lg-3 col-md-4 col-sm-6 col-xs-12'><div class='inline-Div'><img src='../Images/ContactList.png'/></div><div class='inline-Div'><p class='linkBox-title'>Bestyrelsen</p><p class='linkBox-text'>Bestyrelsens kontaktinformationer</p></div></div>"
                });
                Member member = _memberController.GetMemberObject(email);
                LinkPanel.Controls.Add(
new HtmlAnchor()
{
    Target = "_top",
    HRef = "https://k19svenner.sharepoint.com/sites/membersystem/" + member.Name + " " + member.Id + "/Forms/AllItems.aspx",
    InnerHtml =
        "<div class='linkBox col-lg-3 col-md-4 col-sm-6 col-xs-12'><div class='inline-Div'><img src='../Images/Documents.png'/></div><div class='inline-Div'><p class='linkBox-title'>Mine Dokumenter</p><p class='linkBox-text'>Liste med dine personlige dokumenter</p></div></div>"
});

            }
            else
            {
                Response.Write("Din bruger er lukket eller kan ikke findes. Kontakt bestyrelsen.");
            }
            if ((string)Session["MemberType"] == "Bestyrelse")
            {
                LinkPanel.Controls.Add(
                    new HtmlAnchor() { HRef = "CreateMember.aspx", InnerHtml = "<div class='linkBox col-lg-3 col-md-4 col-sm-6 col-xs-12'><div class='inline-Div'><img src='../Images/createMember.png' /></div><div class='inline-Div'><p class='linkBox-title'>Opret Medlem</p><p class='linkBox-text'>Opret medlem i databasen</p></div></div>" });
                LinkPanel.Controls.Add(
                    new HtmlAnchor() { HRef = "SearchMember.aspx", InnerHtml = "<div class='linkBox col-lg-3 col-md-4 col-sm-6 col-xs-12'><div class='inline-Div'><img src='../Images/searchMember.png'/></div><div class='inline-Div'><p class='linkBox-title'>Søg Medlem</p><p class='linkBox-text'>Søg efter og redigér/arkivér medlemmer</p></div></div>" });
                LinkPanel.Controls.Add(
                    new HtmlAnchor() { HRef = "ApproveMember.aspx", InnerHtml = "<div class='linkBox col-lg-3 col-md-4 col-sm-6 col-xs-12'><div class='inline-Div'><img src='../Images/approveMember.png'/></div><div class='inline-Div'><p class='linkBox-title'>Aktivér Medlem</p><p class='linkBox-text'>" + AwaitingActivation() + " medlemmer afventer aktivering</p></div></div>" });
                LinkPanel.Controls.Add(
                    new HtmlAnchor() { HRef = "CreateInvoice.aspx", InnerHtml = "<div class='linkBox col-lg-3 col-md-4 col-sm-6 col-xs-12'><div class='inline-Div'><img src='../Images/AddInvoice.png'/></div><div class='inline-Div'><p class='linkBox-title'>Opret Faktura</p><p class='linkBox-text'>Manuel opretning af faktura</p></div></div>" });
                LinkPanel.Controls.Add(
                        new HtmlAnchor() { HRef = "InvoiceList.aspx", InnerHtml = "<div class='linkBox col-lg-3 col-md-4 col-sm-6 col-xs-12'><div class='inline-Div'><img src='../Images/Invoice.png'/></div><div class='inline-Div'><p class='linkBox-title'>Faktura Liste</p><p class='linkBox-text'>Administrér fakturaer</p></div></div>" });
                LinkPanel.Controls.Add(
                            new HtmlAnchor() { HRef = "SubscriptionList.aspx", InnerHtml = "<div class='linkBox col-lg-3 col-md-4 col-sm-6 col-xs-12'><div class='inline-Div'><img src='../Images/MembershipList.png'/></div><div class='inline-Div'><p class='linkBox-title'>Medlemskabs Liste</p><p class='linkBox-text'>Liste over medlemskaber</p></div></div>" });
                LinkPanel.Controls.Add(
                            new HtmlAnchor() { HRef = "Options.aspx", InnerHtml = "<div class='linkBox col-lg-3 col-md-4 col-sm-6 col-xs-12'><div class='inline-Div'><img src='../Images/Options.png'/></div><div class='inline-Div'><p class='linkBox-title'>Indstillinger</p><p class='linkBox-text'>Diverse indstillinger</p></div></div>" });

            }
        }
        /// <summary>
        /// A method that checks how many members await activation.
        /// </summary>
        /// <returns></returns>
        private int AwaitingActivation()
        {
            return _memberController.NumberOfDeactivatedMembers();
        }

        /// <summary>
        /// A click which redirects the user to the full screen app part. Changes the top location to our destination.
        /// It needs to take the parent location since the button is inside an iframe.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void mobileButton_Click(object sender, EventArgs e)
        {
            Response.Clear();
            Header.Controls.Add(new LiteralControl(@"
<script type=""text/javascript"">
top.location = ""https://membsysintegration.azurewebsites.net/Pages/Default.aspx?SPHostUrl=https%3A%2F%2Fk19svenner%2Esharepoint%2Ecom%2Fsites%2Fmembersystem&SPLanguage=en-US&SPClientTag=2&SPProductNumber=16%2E0%2E4021%2E1224"";
parent.location = ""https://membsysintegration.azurewebsites.net/Pages/Default.aspx?SPHostUrl=https%3A%2F%2Fk19svenner%2Esharepoint%2Ecom%2Fsites%2Fmembersystem&SPLanguage=en-US&SPClientTag=2&SPProductNumber=16%2E0%2E4021%2E1224"";
</script>
"));
        }

    }
}
