﻿using System;
using System.Collections.Generic;
using System.Web.Services;
using SharePointIntegrationWeb.Controller;

namespace SharePointIntegrationWeb.Pages
{
    public partial class EditProfile : System.Web.UI.Page
    {
        static readonly MemberController _memberController = new MemberController();
        private Dictionary<String, String> _memberInfo;
        /// <summary>
        /// Checks if the membertype is "Medlem" or "Bestyrelse", else redirect him back to startpage.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_PreRender(object sender, EventArgs e)
        {
            string memberType = (string)Session["MemberType"];
            if (memberType != "Medlem" && memberType != "Bestyrelse")
            {
                Response.Redirect((string)Session["StartPage"]);
            }
        }
        /// <summary>
        /// Gets the profile info from the database and insert it into input fields.
        /// From the querystring, it determines if it's an admin who edits a user,
        /// or if it's a user editing his own profile.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                string edit = Request.QueryString["edit"];

                if (edit != null)
                {
                    if ((string)Session["MemberType"] == "Bestyrelse" && edit.Equals("member"))
                    {
                        string email = Request.QueryString["email"];
                        _memberInfo = _memberController.GetMember(email);
                        Email.ReadOnly = false;
                        Birthday.ReadOnly = false;
                        MemberType.Enabled = true;
                        MemberType.Visible = true;
                        MemberTypeText.Visible = true;
                        Position.Visible = true;
                        PositionText.Visible = true;
                    }
                }
                else
                {
                    string email = (string)Session["UserEmail"];
                    _memberInfo = _memberController.GetMember(email);
                }

                Name.Text = _memberInfo["Name"];
                Birthday.Text = _memberInfo["Birthday"];
                Address.Text = _memberInfo["Address"];
                Phone.Text = _memberInfo["Phone"];
                ZipCode.Text = _memberInfo["ZipCode"];
                City.Text = _memberInfo["City"];
                Email.Text = _memberInfo["Email"];
                ID.Text = _memberInfo["Id"];
                Position.Text = _memberInfo["Position"];

                if (_memberInfo["MemberType"] == "Bestyrelse")
                {
                    MemberType.SelectedIndex = 0;
                }
                else if (_memberInfo["MemberType"] == "Medlem")
                {
                    Position.ReadOnly = true;
                    MemberType.SelectedIndex = 1;
                }
                else if (_memberInfo["MemberType"] == "Deaktiveret")
                {
                    Position.ReadOnly = true;
                    MemberType.SelectedIndex = 3;
                }
                else
                {
                    Position.ReadOnly = true;
                    MemberType.SelectedIndex = 2;
                }
                MemberType.Text = _memberInfo["MemberType"];
            }
        }
        /// <summary>
        /// Saves all the changes back to the database
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Submit_Click(object sender, EventArgs e)
        {
            String iName = Name.Text;
            String iEmail = Email.Text;
            String iPhone = Phone.Text;
            String iZipCode = ZipCode.Text;
            String iAddress = Address.Text;
            String iCity = City.Text;
            String iBirhtday = Birthday.Text;
            String iId = ID.Text;
            String iMemberType = MemberType.SelectedItem.Text;
            String iPosition = "";
            if (iMemberType != "Medlem")
            {
                iPosition = Position.Text;
            }
            try
            {
                //string id = _memberInfo["Id"];
                string status = _memberController.EditProfile(iId, iName, iEmail, iBirhtday, iPhone, iAddress, iCity, iZipCode, iMemberType, iPosition);

                if (status.Equals("accepted"))
                {
                    statusLabel.Visible = true;
                    statusLabel.Text = "Profilen blev opdateret";
                    errorlabel.Visible = false;
                    _memberInfo = _memberController.GetMember(iEmail);
                }
                else
                {
                    errorlabel.Text = status;
                    errorlabel.Visible = true;
                }
            }
            catch (Exception ex)
            {
                errorlabel.Text = ex.Message;
                Membersystem.ExceptionUtility.LogException(ex, Request.RawUrl);
            }
        }

        protected void Cancel_Click(object sender, EventArgs e)
        {
            Response.Redirect((string)Session["StartPage"]);
        }
        /// <summary>
        /// A web method that works with the client side.
        /// It's an ajax call from the markup file that calls this method.
        /// </summary>
        /// <param name="zipCode">Zip code from input</param>
        /// <returns>City name</returns>
        [WebMethod]
        public static string ZipCode_OnTextChanged(string zipCode)
        {
            string city = _memberController.GetCity(zipCode);
            return city.TrimEnd();
        }
        /// <summary>
        /// Makes the "Role" field available based on if you pick the "Bestyrelse" or "Member"
        /// in the membertype drop down.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void MemberType_OnSelectedIndexChanged(object sender, EventArgs e)
        {
            if (MemberType.SelectedIndex == 0)
            {
                Position.ReadOnly = false;
            }
            else
            {
                Position.ReadOnly = true;
                Position.Text = "";
            }

            string city = City.Text;
            City.ReadOnly = false;
            City.Text = city;
            City.ReadOnly = true;
        }
    }
}