﻿using System;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using SharePointIntegrationWeb.Controller;
using SharePointIntegrationWeb.Model;

namespace SharePointIntegrationWeb.Pages
{
    public partial class InvoiceList : System.Web.UI.Page
    {
        static readonly MemberController _memberController = new MemberController();
        /// <summary>
        /// Checks if the membertype is "Bestyrelse", else redirect him back to startpage.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_PreRender(object sender, EventArgs e)
        {
            string memberType = (string)Session["MemberType"];
            if (memberType != "Bestyrelse")
            {
                Response.Redirect((string)Session["StartPage"]);
            }
        }
        protected void Page_Load(object sender, EventArgs e)
        {

        }
        /// <summary>
        /// When clicking "Submit", it checks if the checkboxes are checked.
        /// It will fire different method based on which checkboxes are checked.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Submit_OnClick(object sender, EventArgs e)
        {
            if (GridView1.Visible)
            {
                foreach (GridViewRow row in GridView1.Rows)
                {
                    if (row.RowType == DataControlRowType.DataRow)
                    {
                        row.Cells[1].Controls.Add(new HtmlAnchor() { HRef = "", InnerText = row.Cells[1].Text });
                        CheckBox chkRow1 = (row.Cells[3].FindControl("paidChkBox") as CheckBox);
                        if (chkRow1.Checked)
                        {
                            _memberController.PayInvoice(row.Cells[0].Text, row.Cells[1].Text);

                        }
                        CheckBox chkRow2 = (row.Cells[4].FindControl("deleteChkBox") as CheckBox);
                        if (chkRow2.Checked && !chkRow1.Checked)
                        {
                            _memberController.DeleteInvoice(row.Cells[0].Text);
                        }
                    }
                }

            }
            if (GridView2.Visible)
            {
                foreach (GridViewRow row in GridView2.Rows)
                {
                    if (row.RowType == DataControlRowType.DataRow)
                    {
                        CheckBox chkRow2 = (row.Cells[4].FindControl("deleteChkBox") as CheckBox);
                        if (chkRow2.Checked)
                        {
                            _memberController.DeleteInvoice(row.Cells[0].Text);
                        }
                    }
                }

            }
            GridView1.DataBind();
            GridView2.DataBind();

        }

        protected void Cancel_OnClick(object sender, EventArgs e)
        {
            Response.Redirect((string)Session["StartPage"]);
        }
        /// <summary>
        /// When changing the view, it will load the other list.
        /// There are two different gridview, one with all the invoices and one with the unpaid ones.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void ChangeView_OnClick(object sender, EventArgs e)
        {
            GridView1.DataBind();
            GridView2.DataBind();
            if (GridView2.Visible == false)
            {
                GridView1.Visible = false;
                GridView2.Visible = true;
            }
            else
            {
                GridView1.Visible = true;
                GridView2.Visible = false;
            }
        }
        /// <summary>
        /// When the gridview is databound, it will load all the dynamically changes to the gridview.
        /// If this is not called, the dynamically changes will be lost during a postback.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void GridView1_OnDataBound(object sender, EventArgs e)
        {
            foreach (GridViewRow row in GridView1.Rows)
            {

                if (row.RowType == DataControlRowType.DataRow)
                {
                    HtmlAnchor htmlAnchor = new HtmlAnchor()
                    {
                        InnerText = row.Cells[1].Text
                    };

                    string MemberId = _memberController.GetMemberIdBySubNr((row.Cells[1].Text));
                    Member member = _memberController.GetMemberObject(Int32.Parse(MemberId));
                    htmlAnchor.HRef = "#";
                    htmlAnchor.Attributes.Add("onclick", "ShowMemberInfo(\'" + member.Name + "\',\'" + member.Email + "\',\'" + MemberId + "\')");
                    row.Cells[1].Controls.Add(htmlAnchor);
                }
            }
        }
        /// <summary>
        /// When the gridview is databound, it will load all the dynamically changes to the gridview.
        /// If this is not called, the dynamically changes will be lost during a postback.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void GridView2_OnDataBound(object sender, EventArgs e)
        {
            foreach (GridViewRow row in GridView2.Rows)
            {

                if (row.RowType == DataControlRowType.DataRow)
                {
                    HtmlAnchor htmlAnchor = new HtmlAnchor()
                    {
                        InnerText = row.Cells[1].Text
                    };

                    string MemberId = _memberController.GetMemberIdBySubNr((row.Cells[1].Text));
                    Member member = _memberController.GetMemberObject(Int32.Parse(MemberId));
                    htmlAnchor.HRef = "#";
                    htmlAnchor.Attributes.Add("onclick", "ShowMemberInfo(\'" + member.Name + "\',\'" + member.Email + "\',\'" + MemberId + "\')");
                    row.Cells[1].Controls.Add(htmlAnchor);
                }
            }
        }
    }
}