﻿using System;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using SharePointIntegrationWeb.Controller;

namespace SharePointIntegrationWeb.Pages
{
    public partial class SearchMember : System.Web.UI.Page
    {
        private readonly MemberController _memberController = new MemberController();
        /// <summary>
        /// Checks if the membertype is "Bestyrelse", else redirect him back to startpage.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_PreRender(object sender, EventArgs e)
        {
            string memberType = (string)Session["MemberType"];
            if (memberType != "Bestyrelse")
            {
                Response.Redirect((string)Session["StartPage"]);
            }
        }
        protected void Page_Load(object sender, EventArgs e)
        {
            MemberNameTextBox.Focus();
        }
        /// <summary>
        /// When the input for membername is changed, it will search for members.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void MemberNameTextBox_TextChanged(object sender, EventArgs e)
        {
            try
            {
                var foundMembers = _memberController.SearchMember(MemberNameTextBox.Text);
                if (foundMembers.Count != 0)
                {
                    //AddFoundMembersToPanel(foundMembers);
                }
                else
                {
                    SearchError.Visible = true;
                    SearchError.InnerText = "Din søgning gav ikke noget resultat";
                }
            }
            catch (Exception ex)
            {
                SearchError.Visible = true;
                SearchError.InnerText = ex.Message;
                Membersystem.ExceptionUtility.LogException(ex, Request.RawUrl);
            }
        }

        protected void BackButton_Click(object sender, EventArgs e)
        {
            Response.Redirect((string)Session["StartPage"]);
        }

        /// <summary>
        /// When the gridview is databound, it will load all the dynamically changes to the gridview.
        /// If this is not called, the dynamically changes will be lost during a postback.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void GridView1_OnRowDataBound(object sender, GridViewRowEventArgs e)
        {
            if (e.Row.RowType == DataControlRowType.DataRow)
            {
                string status = "Arkivér";
                if (e.Row.Cells[2].Text == "Arkiveret")
                    status = "Åben";
                HtmlAnchor popupLink = new HtmlAnchor() { HRef = "#", InnerText = status };
                popupLink.Attributes.Add("onclick", "Confirm(\'" + e.Row.Cells[1].Text + "\', \'" + status + "\')");
                e.Row.Cells[4].Controls.Add(popupLink);
            }
        }
    }
}