﻿using System;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using SharePointIntegrationWeb.Controller;
using SharePointIntegrationWeb.Model;

namespace SharePointIntegrationWeb.Pages
{
    public partial class SubscriptionList : System.Web.UI.Page
    {
        static readonly MemberController _memberController = new MemberController();
        /// <summary>
        /// Checks if the membertype is "Bestyrelse", else redirect him back to startpage.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_PreRender(object sender, EventArgs e)
        {
            string memberType = (string)Session["MemberType"];
            if (memberType != "Bestyrelse")
            {
                Response.Redirect((string)Session["StartPage"]);
            }

        }
        protected void Page_Load(object sender, EventArgs e)
        {
           
            
        }
        /// <summary>
        /// When the gridview is databound, it will load all the dynamically changes to the gridview.
        /// If this is not called, the dynamically changes will be lost during a postback.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void GridView1_OnDataBound(object sender, EventArgs e)
        {
            foreach (GridViewRow row in GridView1.Rows)
            {
                
                if (row.RowType == DataControlRowType.DataRow)
                {
                    try
                    {
                        ConvertToShortDateTime(row);
                        InsertMemberName(row);
                    }
                    catch (Exception ex)
                    {
                        Response.Write(ex.Message);
                    }
                }
            }
        }

        /// <summary>
        /// Called from the GridView databound event.
        /// This inserts the member name based on the id in the first cell of the row.
        /// </summary>
        /// <param name="row">The whole row of the GridView. 1 row = 1 subscription</param>
        private void InsertMemberName(GridViewRow row)
        {
            row.Cells[2].Text = _memberController.GetMemberObject(Int32.Parse(row.Cells[1].Text)).Name;
        }
        /// <summary>
        /// Converts the date to a danish date format
        /// </summary>
        /// <param name="row"></param>
        private static void ConvertToShortDateTime(GridViewRow row)
        {
            DateTime dt = Convert.ToDateTime(row.Cells[3].Text);

            string date = dt.ToString("dd/MM/yyyy");
            row.Cells[3].Text = date;
        }

        protected void BackButton_Click(object sender, EventArgs e)
        {
            Response.Redirect((string)Session["StartPage"]);
        }

    }
}