﻿using System;
using System.Collections;
using System.Net;
using System.Security;
using System.Web.ModelBinding;
using Microsoft.SharePoint.Client;

namespace SharePointIntegrationWeb
{
    static class SharePointHelper
    {
        /// <summary>
        /// Uploads the invoice to SharePoint document library.
        /// </summary>
        /// <param name="filepath">Filepath for the file that needs to be uploaded</param>
        /// <param name="listName">List of the name, where the file gets uploaded</param>
        /// <param name="cc">Clientcontext which is created when the user logs in</param>
        /// <returns></returns>
        public static string UploadInvoice(string filepath, string listName, ClientContext cc)
        {
  
                try
                {
                    Web web = cc.Web;
                    cc.Load(web);
                    cc.ExecuteQuery();

                    List list = web.Lists.GetByTitle(listName);
                    cc.Load(list);
                    cc.ExecuteQuery();
                    FileCreationInformation fci = new FileCreationInformation();
                    fci.Content = System.IO.File.ReadAllBytes(filepath);
                    fci.Url = listName + " - Faktura.pdf";
                    fci.Overwrite = true;
                    cc.Load(list.RootFolder);
                    cc.ExecuteQuery();
                    cc.Load(list.RootFolder.Files);
                    cc.ExecuteQuery();
                    int itemsCount = list.RootFolder.Files.Count;
                    if (itemsCount > 0)
                    {
                        fci.Url = listName + " - Faktura"+itemsCount+".pdf";
                    }
                    list.RootFolder.Files.Add(fci);
                    cc.ExecuteQuery();
                    return "success";
                }
                catch (Exception ex)
                {
                    return ex.Message;

                }
            
        }
        /// <summary>
        /// Creates a document library for the member using his name to name the library.
        /// </summary>
        /// <param name="email">Member Email which goes in the description</param>
        /// <param name="name">Member Name which is used to name the library also</param>
        /// <param name="cc">Clientcontext which is created when the user logs in</param>
        /// <returns></returns>
        public static string CreateMemberList(string email, string name, ClientContext cc)
        {
            try
            {
                Web web = cc.Web;
                cc.Load(web);
                cc.ExecuteQuery();

                ListCreationInformation lci = new ListCreationInformation();
                lci.Title = name;
                lci.TemplateType = (int) ListTemplateType.DocumentLibrary;
                List list = web.Lists.Add(lci);

                list.Description = name + "'s dokumenter. Email: " + email;
                list.Update();
                cc.ExecuteQuery();

                web.Update();
                cc.ExecuteQuery();
                return "success";
            }
            catch (Exception ex)
            {
                return ex.Message;
            }
        }

    }
}
